@@ -86,7 +86,7 @@
 #define KBOOKMARKS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KBOOKMARKS_NO_DEPRECATED
-#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54300
+#  define KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54600
 #endif
 #ifdef KBOOKMARKS_NO_DEPRECATED_WARNINGS
 #  define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE KBOOKMARKS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x54300
+#    define KBOOKMARKS_DEPRECATED_WARNINGS_SINCE 0x54600
 #  endif
 #endif
 
@@ -121,6 +121,12 @@
 #else
 #  define KBOOKMARKS_DEPRECATED_VERSION_5_65(text)
 #endif
+
+#if KBOOKMARKS_DEPRECATED_WARNINGS_SINCE >= 0x54500
+#  define KBOOKMARKS_DEPRECATED_VERSION_5_69(text) KBOOKMARKS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KBOOKMARKS_DEPRECATED_VERSION_5_69(text)
+#endif
 #define KBOOKMARKS_DEPRECATED_VERSION_5(minor, text)      KBOOKMARKS_DEPRECATED_VERSION_5_##minor(text)
 #define KBOOKMARKS_DEPRECATED_VERSION(major, minor, text) KBOOKMARKS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 
